Fisheye: Tag 6133 refers to a dead (removed) revision in file `DamEngine/trunk/src/Deltares.DamEngine.Calculators.Tests/KernelWrappers/Common/DamPipingHelperTests.cs'.
Fisheye: No comparison available. Pass `N' to diff?
Fisheye: Tag 6133 refers to a dead (removed) revision in file `DamEngine/trunk/src/Deltares.DamEngine.Calculators/KernelWrappers/Common/DamPipingHelper.cs'.
Fisheye: No comparison available. Pass `N' to diff?
Index: DamEngine/trunk/src/Deltares.DamEngine.Calculators/Properties/Resources.resx
===================================================================
diff -u -r6077 -r6133
--- DamEngine/trunk/src/Deltares.DamEngine.Calculators/Properties/Resources.resx (.../Resources.resx) (revision 6077)
+++ DamEngine/trunk/src/Deltares.DamEngine.Calculators/Properties/Resources.resx (.../Resources.resx) (revision 6133)
@@ -132,10 +132,10 @@
Validation failed for location '{0}', subsoil scenario '{1}', design scenario '{2}'
-
+
No input object defined for Bligh
-
+
No output object defined for Bligh
@@ -182,7 +182,7 @@
After height adaption ditch does not fit inside surfaceline anymore.
- The heigth of the dike top is equal to or lower than the dike toe so redesign is NOT possible.
+ The height of the dike top is equal to or lower than the dike toe so redesign is NOT possible.
New shoulder height is smaller than current shoulder height.
@@ -205,7 +205,7 @@
The new shoulder length is too large to fit in the current surface line.
-
+
No Dam input object defined for Bligh
Index: DamEngine/trunk/src/Deltares.DamEngine.Calculators.Tests/KernelWrappers/Common/DamPipingHelperTests.cs
===================================================================
diff -u -r4624 -r6133
--- DamEngine/trunk/src/Deltares.DamEngine.Calculators.Tests/KernelWrappers/Common/DamPipingHelperTests.cs (.../DamPipingHelperTests.cs) (revision 4624)
+++ DamEngine/trunk/src/Deltares.DamEngine.Calculators.Tests/KernelWrappers/Common/DamPipingHelperTests.cs (.../WtiPipingHelperTests.cs) (revision 6133)
@@ -25,7 +25,7 @@
namespace Deltares.DamEngine.Calculators.Tests.KernelWrappers.Common;
[TestFixture]
-public class DamPipingHelperTests
+public class WtiPipingHelperTests
{
[Test]
public void TestDetermineHeightCoverLayer()
@@ -34,14 +34,14 @@
var topLevelAquifer = 3.0;
var surfaceLevel = 5.0;
// expected height = 5 - 3 = 2
- double height = DamPipingHelper.DetermineHeightCoverLayer(topLevelAquifer, surfaceLevel);
+ double height = WtiPipingHelper.DetermineHeightCoverLayer(topLevelAquifer, surfaceLevel);
Assert.That(height, Is.EqualTo(2.0));
// Top of aquifer is above surface level
topLevelAquifer = 3.0;
surfaceLevel = 1.0;
// expected height = 0
- height = DamPipingHelper.DetermineHeightCoverLayer(topLevelAquifer, surfaceLevel);
+ height = WtiPipingHelper.DetermineHeightCoverLayer(topLevelAquifer, surfaceLevel);
Assert.That(height, Is.EqualTo(0.0));
}
}
\ No newline at end of file
Index: DamEngine/trunk/src/Deltares.DamEngine.Calculators/Properties/Resources.nl-NL.resx
===================================================================
diff -u -r6077 -r6133
--- DamEngine/trunk/src/Deltares.DamEngine.Calculators/Properties/Resources.nl-NL.resx (.../Resources.nl-NL.resx) (revision 6077)
+++ DamEngine/trunk/src/Deltares.DamEngine.Calculators/Properties/Resources.nl-NL.resx (.../Resources.nl-NL.resx) (revision 6133)
@@ -126,13 +126,13 @@
Het opgegeven niveau {0} in AquitardEvaluator valt buiten het grondprofiel '{1}' en moet tussen {2} en {3} liggen.
-
+
Geen Dam invoer object gedefinieerd voor Bligh
-
+
Geen invoer object gedefinieerd voor Bligh
-
+
Geen uitvoer object gedefinieerd voor Bligh
@@ -168,12 +168,6 @@
Er is geen teen van de dijk voor de hoogtegeometrie gedfinieerd in locatie '{0}'.
-
- Er is geen 1D grondprofiel gedefinieerd voor locatie '{0}'.
-
-
- Er is geen hoogtegeometrie gedefinieerd voor locatie '{0}'.
-
Locatie '{0}', ondergrond profiel '{1}', tijdstap '{2}', tijdstip '{3}': De berekening is mislukt met de volgende foutmelding '{4}'.
Index: DamEngine/trunk/src/Deltares.DamEngine.Calculators/Properties/Resources.Designer.cs
===================================================================
diff -u -r6077 -r6133
--- DamEngine/trunk/src/Deltares.DamEngine.Calculators/Properties/Resources.Designer.cs (.../Resources.Designer.cs) (revision 6077)
+++ DamEngine/trunk/src/Deltares.DamEngine.Calculators/Properties/Resources.Designer.cs (.../Resources.Designer.cs) (revision 6133)
@@ -72,27 +72,27 @@
///
/// Looks up a localized string similar to No Dam input object defined for Bligh.
///
- internal static string DamPipingBlighKernelWrapper_NoDamInputObjectDefinedForBligh {
+ internal static string WtiPipingBlighKernelWrapper_NoDamInputObjectDefinedForBligh {
get {
- return ResourceManager.GetString("DamPipingBlighKernelWrapper_NoDamInputObjectDefinedForBligh", resourceCulture);
+ return ResourceManager.GetString("WtiPipingBlighKernelWrapper_NoDamInputObjectDefinedForBligh", resourceCulture);
}
}
///
/// Looks up a localized string similar to No input object defined for Bligh.
///
- internal static string DamPipingBlighKernelWrapper_NoInputObjectDefinedForBligh {
+ internal static string WtiPipingBlighKernelWrapper_NoInputObjectDefinedForBligh {
get {
- return ResourceManager.GetString("DamPipingBlighKernelWrapper_NoInputObjectDefinedForBligh", resourceCulture);
+ return ResourceManager.GetString("WtiPipingBlighKernelWrapper_NoInputObjectDefinedForBligh", resourceCulture);
}
}
///
/// Looks up a localized string similar to No output object defined for Bligh.
///
- internal static string DamPipingBlighKernelWrapper_NoOutputObjectDefinedForBligh {
+ internal static string WtiPipingBlighKernelWrapper_NoOutputObjectDefinedForBligh {
get {
- return ResourceManager.GetString("DamPipingBlighKernelWrapper_NoOutputObjectDefinedForBligh", resourceCulture);
+ return ResourceManager.GetString("WtiPipingBlighKernelWrapper_NoOutputObjectDefinedForBligh", resourceCulture);
}
}
Index: DamEngine/trunk/src/Deltares.DamEngine.Calculators/KernelWrappers/WtiPipingBligh/WtiPipingBlighKernelWrapper.cs
===================================================================
diff -u -r6132 -r6133
--- DamEngine/trunk/src/Deltares.DamEngine.Calculators/KernelWrappers/WtiPipingBligh/WtiPipingBlighKernelWrapper.cs (.../WtiPipingBlighKernelWrapper.cs) (revision 6132)
+++ DamEngine/trunk/src/Deltares.DamEngine.Calculators/KernelWrappers/WtiPipingBligh/WtiPipingBlighKernelWrapper.cs (.../WtiPipingBlighKernelWrapper.cs) (revision 6133)
@@ -62,21 +62,21 @@
///
public PrepareResult Prepare(DamKernelInput damKernelInput, int iterationIndex, out IKernelDataInput kernelDataInput, out IKernelDataOutput kernelDataOutput)
{
- var damPipingBlighOutput = new WtiPipingBlighOutput
+ var wtiPipingBlighOutput = new WtiPipingBlighOutput
{
CalculationResult = CalculationResult.NoRun,
FoSp = defaultMaxReturnValue
};
- kernelDataOutput = damPipingBlighOutput;
+ kernelDataOutput = wtiPipingBlighOutput;
if (damKernelInput.SubSoilScenario.SegmentFailureMechanismType.Value.In(SegmentFailureMechanismType.Piping, SegmentFailureMechanismType.All))
{
- var damPipingBlighInput = new WtiPipingBlighInput();
+ var wtiPipingBlighInput = new WtiPipingBlighInput();
SoilProfile1D soilProfile1D = damKernelInput.SubSoilScenario.SoilProfile1D;
Location location = damKernelInput.Location;
double waterLevel = damKernelInput.RiverLevelHigh;
PlLines plLines = PlLinesHelper.CreatePlLinesForPiping(damKernelInput.TimeStepDateTime, location, soilProfile1D, waterLevel);
- if (EvaluateUpliftSituation(damKernelInput, out kernelDataInput, plLines, damPipingBlighInput, waterLevel, damPipingBlighOutput))
+ if (EvaluateUpliftSituation(damKernelInput, out kernelDataInput, plLines, wtiPipingBlighInput, waterLevel, wtiPipingBlighOutput))
{
return PrepareResult.Successful;
}
@@ -97,7 +97,7 @@
///
public int Validate(IKernelDataInput kernelDataInput, IKernelDataOutput kernelDataOutput, out List messages)
{
- var damPipingBlighOutput = (WtiPipingBlighOutput) kernelDataOutput;
+ var wtiPipingBlighOutput = (WtiPipingBlighOutput) kernelDataOutput;
BlighCalculator calculatorBligh = CreateWtiPipingCalculatorBligh(kernelDataInput);
List kernelMessages = calculatorBligh.Validate();
messages = new List();
@@ -112,7 +112,7 @@
if (messages.Count > 0)
{
- damPipingBlighOutput.CalculationResult = CalculationResult.InvalidInputData;
+ wtiPipingBlighOutput.CalculationResult = CalculationResult.InvalidInputData;
}
return messages.Count;
@@ -127,11 +127,11 @@
/// No input object defined for Bligh
public void Execute(IKernelDataInput kernelDataInput, IKernelDataOutput kernelDataOutput, out List messages)
{
- var damPipingBlighInput = kernelDataInput as WtiPipingBlighInput;
- var damPipingBlighOutput = (WtiPipingBlighOutput) kernelDataOutput;
- ThrowWhenKernelInputNull(damPipingBlighInput);
- ThrowWhenKernelOutputNull(damPipingBlighOutput);
- PerformSingleCalculationBligh(out messages, damPipingBlighOutput, damPipingBlighInput);
+ var wtiPipingBlighInput = kernelDataInput as WtiPipingBlighInput;
+ var wtiPipingBlighOutput = (WtiPipingBlighOutput) kernelDataOutput;
+ ThrowWhenKernelInputNull(wtiPipingBlighInput);
+ ThrowWhenKernelOutputNull(wtiPipingBlighOutput);
+ PerformSingleCalculationBligh(out messages, wtiPipingBlighOutput, wtiPipingBlighInput);
}
///
@@ -147,25 +147,25 @@
DesignScenario designScenario, string resultMessage,
out List designResults)
{
- var damPipingBlighOutput = kernelDataOutput as WtiPipingBlighOutput;
+ var wtiPipingBlighOutput = kernelDataOutput as WtiPipingBlighOutput;
ThrowWhenDamKernelInputNull(damKernelInput);
- ThrowWhenKernelOutputNull(damPipingBlighOutput);
+ ThrowWhenKernelOutputNull(wtiPipingBlighOutput);
designResults = new List();
var designResult = new DesignResult(damKernelInput.DamFailureMechanismeCalculationSpecification,
designScenario, damKernelInput.SubSoilScenario.SoilProfile1D, null)
{
- CalculationResult = damPipingBlighOutput.CalculationResult
+ CalculationResult = wtiPipingBlighOutput.CalculationResult
};
var pipingDesignResults = new PipingDesignResults(PipingModelType.Bligh);
designResult.PipingDesignResults = pipingDesignResults;
pipingDesignResults.ResultMessage = resultMessage;
- pipingDesignResults.BlighFactor = damPipingBlighOutput.FoSp;
- pipingDesignResults.BlighHcritical = damPipingBlighOutput.Hc;
+ pipingDesignResults.BlighFactor = wtiPipingBlighOutput.FoSp;
+ pipingDesignResults.BlighHcritical = wtiPipingBlighOutput.Hc;
pipingDesignResults.RedesignedSurfaceLine = damKernelInput.Location.SurfaceLine;
- pipingDesignResults.UpliftSituation = damPipingBlighOutput.UpliftSituation;
- pipingDesignResults.LocalExitPointX = damPipingBlighOutput.ExitPointX;
- pipingDesignResults.UpliftFactor = damPipingBlighOutput.UpliftFactor;
+ pipingDesignResults.UpliftSituation = wtiPipingBlighOutput.UpliftSituation;
+ pipingDesignResults.LocalExitPointX = wtiPipingBlighOutput.ExitPointX;
+ pipingDesignResults.UpliftFactor = wtiPipingBlighOutput.UpliftFactor;
designResults.Add(designResult);
}
@@ -181,17 +181,17 @@
public ShoulderDesign CalculateDesignAtPoint(DamKernelInput damKernelInput, IKernelDataInput kernelDataInput, IKernelDataOutput kernelDataOutput, Point2D point, out List messages)
{
messages = new List();
- var damPipingBlighInput = kernelDataInput as WtiPipingBlighInput;
- var damPipingBlighOutput = (WtiPipingBlighOutput) kernelDataOutput;
+ var wtiPipingBlighInput = kernelDataInput as WtiPipingBlighInput;
+ var wtiPipingBlighOutput = (WtiPipingBlighOutput) kernelDataOutput;
ThrowWhenDamKernelInputNull(damKernelInput);
- ThrowWhenKernelOutputNull(damPipingBlighOutput);
+ ThrowWhenKernelOutputNull(wtiPipingBlighOutput);
Location location = damKernelInput.Location;
SoilProfile1D soilProfile = damKernelInput.SubSoilScenario.SoilProfile1D;
SurfaceLine2 surfaceLine = damKernelInput.Location.SurfaceLine;
PlLines plLines;
UpliftLocationAndResult upliftLocationAndResult;
- DamPipingHelper.DeterminePlLinesAndUpliftLocation(damKernelInput, point, out plLines, out upliftLocationAndResult);
+ WtiPipingHelper.DeterminePlLinesAndUpliftLocation(damKernelInput, point, out plLines, out upliftLocationAndResult);
double requiredFoS = location.ModelFactors.RequiredSafetyFactorPiping;
double upliftCriterion = location.UpliftCriterionPiping;
@@ -200,20 +200,20 @@
{
double xEntry = surfaceLine.CharacteristicPoints.GetPoint2D(CharacteristicPointType.DikeToeAtRiver).X;
double xExit = upliftLocationAndResult.X;
- damPipingBlighInput.SeepageLength = xExit - xEntry;
+ wtiPipingBlighInput.SeepageLength = xExit - xEntry;
double topLevelAquifer = soilProfile.GetLayerWithName(upliftLocationAndResult.LayerWhereUpliftOccuresId).TopLevel;
// The following 2 parameters are dependent on the position of the point and have to be recalculated for the current point
- double dCoverLayer = DamPipingHelper.DetermineHeightCoverLayer(topLevelAquifer, point.Z); // point.Z is surfacelevel
- damPipingBlighInput.DTotal = dCoverLayer;
+ double dCoverLayer = WtiPipingHelper.DetermineHeightCoverLayer(topLevelAquifer, point.Z); // point.Z is surfacelevel
+ wtiPipingBlighInput.DTotal = dCoverLayer;
double referenceLevel = Math.Max(location.CurrentScenario.PolderLevel, point.Z); // point.Z is surfacelevel
- damPipingBlighInput.HExit = referenceLevel;
+ wtiPipingBlighInput.HExit = referenceLevel;
// Calculate the piping safety factor using the level of the given point
- PerformSingleCalculationBligh(out messages, damPipingBlighOutput, damPipingBlighInput);
+ PerformSingleCalculationBligh(out messages, wtiPipingBlighOutput, wtiPipingBlighInput);
// If too low, then determine required height and length (from uplift)
- if (damPipingBlighOutput.FoSp < requiredFoS)
+ if (wtiPipingBlighOutput.FoSp < requiredFoS)
{
// Finally, determine the required shoulderheight
double currentShoulderHeight = upliftLocationAndResult.Z -
@@ -243,13 +243,13 @@
public bool EvaluateDesign(DamKernelInput damKernelInput, IKernelDataInput kernelDataInput, IKernelDataOutput kernelDataOutput,
out DesignAdvise designAdvise, out string evaluationMessage)
{
- var damPipingBlighInput = kernelDataInput as WtiPipingBlighInput;
- var damPipingBlighOutput = (WtiPipingBlighOutput) kernelDataOutput;
- ThrowWhenKernelInputNull(damPipingBlighInput);
+ var wtiPipingBlighInput = kernelDataInput as WtiPipingBlighInput;
+ var wtiPipingBlighOutput = (WtiPipingBlighOutput) kernelDataOutput;
+ ThrowWhenKernelInputNull(wtiPipingBlighInput);
ThrowWhenDamKernelInputNull(damKernelInput);
- ThrowWhenKernelOutputNull(damPipingBlighOutput);
+ ThrowWhenKernelOutputNull(wtiPipingBlighOutput);
double fosRequired = damKernelInput.Location.ModelFactors.RequiredSafetyFactorPiping;
- double fosAchieved = damPipingBlighOutput.FoSp;
+ double fosAchieved = wtiPipingBlighOutput.FoSp;
evaluationMessage = String.Format(Resources.FactorAchievedVsFactorRequired, fosAchieved, fosRequired);
designAdvise = DesignAdvise.None;
return (fosAchieved >= fosRequired);
@@ -299,7 +299,7 @@
SoilLayer1D heaveLayer = soilProfile1D.GetLayerWithName(upliftLocationAndResult.LayerWhereUpliftOccuresId);
double d70 = Physics.FactorMeterToMicroMeter * heaveLayer.Soil.DiameterD70;
double topLevelAquifer = soilProfile1D.GetLayerWithName(upliftLocationAndResult.LayerWhereUpliftOccuresId).TopLevel;
- double dCoverLayer = DamPipingHelper.DetermineHeightCoverLayer(topLevelAquifer, surfaceLevel);
+ double dCoverLayer = WtiPipingHelper.DetermineHeightCoverLayer(topLevelAquifer, surfaceLevel);
double? upliftFactor = upliftLocationAndResult.UpliftFactor;
double seepageLength = xExit - xEntry;
wtiPipingBlighInput.HRiver = waterLevel;
@@ -362,16 +362,16 @@
/// No input object defined for Bligh
private BlighCalculator CreateWtiPipingCalculatorBligh(IKernelDataInput kernelDataInput)
{
- var damPipingBlighInput = kernelDataInput as WtiPipingBlighInput;
- ThrowWhenKernelInputNull(damPipingBlighInput);
+ var wtiPipingBlighInput = kernelDataInput as WtiPipingBlighInput;
+ ThrowWhenKernelInputNull(wtiPipingBlighInput);
var calculator = new BlighCalculator
{
- HRiver = damPipingBlighInput.HRiver,
- HExit = damPipingBlighInput.HExit,
- Rc = damPipingBlighInput.Rc,
- DTotal = damPipingBlighInput.DTotal,
- SeepageLength = damPipingBlighInput.SeepageLength,
- D50 = 0.81 * damPipingBlighInput.D70 * Physics.FactorMicroMeterToMeter,
+ HRiver = wtiPipingBlighInput.HRiver,
+ HExit = wtiPipingBlighInput.HExit,
+ Rc = wtiPipingBlighInput.Rc,
+ DTotal = wtiPipingBlighInput.DTotal,
+ SeepageLength = wtiPipingBlighInput.SeepageLength,
+ D50 = 0.81 * wtiPipingBlighInput.D70 * Physics.FactorMicroMeterToMeter,
ModelFactorPiping = 1
};
return calculator;
@@ -381,23 +381,23 @@
{
if (wtiPipingBlighInput == null)
{
- throw new NoNullAllowedException(Resources.DamPipingBlighKernelWrapper_NoInputObjectDefinedForBligh);
+ throw new NoNullAllowedException(Resources.WtiPipingBlighKernelWrapper_NoInputObjectDefinedForBligh);
}
}
private void ThrowWhenKernelOutputNull(WtiPipingBlighOutput wtiPipingBlighOutput)
{
if (wtiPipingBlighOutput == null)
{
- throw new NoNullAllowedException(Resources.DamPipingBlighKernelWrapper_NoOutputObjectDefinedForBligh);
+ throw new NoNullAllowedException(Resources.WtiPipingBlighKernelWrapper_NoOutputObjectDefinedForBligh);
}
}
private void ThrowWhenDamKernelInputNull(DamKernelInput damKernelInput)
{
if (damKernelInput == null)
{
- throw new NoNullAllowedException(Resources.DamPipingBlighKernelWrapper_NoDamInputObjectDefinedForBligh);
+ throw new NoNullAllowedException(Resources.WtiPipingBlighKernelWrapper_NoDamInputObjectDefinedForBligh);
}
}
}
\ No newline at end of file
Index: DamEngine/trunk/src/Deltares.DamEngine.Calculators/KernelWrappers/Common/DamPipingHelper.cs
===================================================================
diff -u -r6107 -r6133
--- DamEngine/trunk/src/Deltares.DamEngine.Calculators/KernelWrappers/Common/DamPipingHelper.cs (.../DamPipingHelper.cs) (revision 6107)
+++ DamEngine/trunk/src/Deltares.DamEngine.Calculators/KernelWrappers/Common/DamPipingHelper.cs (.../WtiPipingHelper.cs) (revision 6133)
@@ -31,9 +31,9 @@
namespace Deltares.DamEngine.Calculators.KernelWrappers.Common;
///
/// Helper for Dam Piping kernels
///
-public static class DamPipingHelper
+public static class WtiPipingHelper
{
///
/// Determines the total thickness of the cover layer.
@@ -31,9 +31,9 @@
namespace Deltares.DamEngine.Calculators.KernelWrappers.Common;
///
-/// Helper for Dam Piping kernels
+/// Helper for Wti Piping kernel
///